@@ -1,4 +1,4 @@
-//@line 40 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 40 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/toolkit/content/contentAreaUtils.js"
 
 
 /**
@@ -244,7 +244,13 @@ function internalSave(aURL, aDocument, aDefaultFileName, aContentDisposition,
   if (aChosenData)
     file = aChosenData.file;
   else {
-    initFileInfo(fileInfo, aURL, aDocument, aContentType, aContentDisposition);
+    var charset = null;
+    if (aDocument)
+      charset = aDocument.characterSet;
+    else if (aReferrer)
+      charset = aReferrer.originCharset;
+    initFileInfo(fileInfo, aURL, aDocument, aContentType, aContentDisposition,
+                 charset);
     var fpParams = {
       fpTitleKey: aFilePickerTitleKey,
       isDocument: isDocument,
@@ -389,14 +395,17 @@ function FileInfo(aSuggestedFileName, aFileName, aFileBaseName, aFileExt, aUri)
  *        determined by the caller.
  * @param aContentDisposition The content-disposition header for the object
  *        we're saving, if it could be determined by the caller.
+ * @param aURLCharset The charset of aURL.
  */
-function initFileInfo(aFI, aURL, aDocument, aContentType, aContentDisposition)
+function initFileInfo(aFI, aURL, aDocument, aContentType, aContentDisposition,
+                      aURLCharset)
 {
-  var docCharset = (aDocument ? aDocument.characterSet : null);
+  if (!aURLCharset && aDocument && aDocument.characterSet)
+    aURLCharset = aDocument.characterSet;
   try {
     // Get an nsIURI object from aURL if possible:
     try {
-      aFI.uri = makeURI(aURL, docCharset);
+      aFI.uri = makeURI(aURL, aURLCharset);
       // Assuming nsiUri is valid, calling QueryInterface(...) on it will
       // populate extra object fields (eg filename and file extension).
       var url = aFI.uri.QueryInterface(Components.interfaces.nsIURL);
@@ -451,9 +460,9 @@ function getTargetFile(aFpP, aSkipPrompt)
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
     
-//@line 498 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 507 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/toolkit/content/contentAreaUtils.js"
     return "Home";
-//@line 501 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 510 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/toolkit/content/contentAreaUtils.js"
   }
   
   function getDownloadsFolder(aFolder)
@@ -841,7 +850,7 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 892 "/usr/local/src/Plamo/plamo/gnm/firefox/.work/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 901 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/toolkit/content/contentAreaUtils.js"
       
   // Fix up the file name we're saving to to include the default extension
   var i = aFile.lastIndexOf(".");
