@@ -267,19 +267,30 @@ pref("capability.policy.default.Navigator.preferenceinternal.set", "UniversalPre
 
 pref("capability.policy.default.Window.blur.get", "allAccess");
 pref("capability.policy.default.Window.close.get", "allAccess");
-pref("capability.policy.default.Window.closed", "allAccess");
+pref("capability.policy.default.Window.closed.get", "allAccess");
 pref("capability.policy.default.Window.Components", "allAccess");
-pref("capability.policy.default.Window.document", "allAccess");
+pref("capability.policy.default.Window.document.get", "allAccess");
 pref("capability.policy.default.Window.focus.get", "allAccess");
-pref("capability.policy.default.Window.frames", "allAccess");
-pref("capability.policy.default.Window.history", "allAccess");
-pref("capability.policy.default.Window.length", "allAccess");
+pref("capability.policy.default.Window.frames.get", "allAccess");
+pref("capability.policy.default.Window.history.get", "allAccess");
+pref("capability.policy.default.Window.length.get", "allAccess");
 pref("capability.policy.default.Window.location", "allAccess");
-pref("capability.policy.default.Window.opener", "allAccess");
-pref("capability.policy.default.Window.parent", "allAccess");
-pref("capability.policy.default.Window.self", "allAccess");
-pref("capability.policy.default.Window.top", "allAccess");
-pref("capability.policy.default.Window.window", "allAccess");
+pref("capability.policy.default.Window.opener.get", "allAccess");
+pref("capability.policy.default.Window.parent.get", "allAccess");
+pref("capability.policy.default.Window.self.get", "allAccess");
+pref("capability.policy.default.Window.top.get", "allAccess");
+pref("capability.policy.default.Window.window.get", "allAccess");
+
+pref("capability.policy.default.XULControllers.commandDispatcher", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerForCommand", "noAccess");
+pref("capability.policy.default.XULControllers.insertControllerAt", "noAccess");
+pref("capability.policy.default.XULControllers.removeControllerAt", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerAt", "noAccess");
+pref("capability.policy.default.XULControllers.appendController", "noAccess");
+pref("capability.policy.default.XULControllers.removeController", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerId", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerById", "noAccess");
+pref("capability.policy.default.XULControllers.getControllerCount", "noAccess");
 
 // Restrictions on the DOM for mail/news - see bugs 66938 and 84545
 pref("capability.policy.mailnews.sites", "mailbox: imap: news:");
@@ -462,7 +473,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 471 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 482 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -657,7 +668,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 671 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 682 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -792,7 +803,7 @@ pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 840 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 851 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -809,7 +820,7 @@ pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withmetakey.action",2);
 pref("mousewheel.horizscroll.withmetakey.numlines",-1);
 pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
-//@line 857 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 868 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -942,15 +953,15 @@ pref("dom.max_script_run_time", 5);
 
 pref("svg.enabled", true);
 
-//@line 1320 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1331 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1507 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1518 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1696 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1707 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1777 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1788 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1780 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1791 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1026,7 +1037,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1856 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1867 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.name.serif.el", "serif");
 pref("font.name.sans-serif.el", "sans-serif");
@@ -1085,7 +1096,7 @@ pref("font.name.sans-serif.zh-HK", "sans-serif");
 pref("font.name.monospace.zh-HK", "monospace");
 
 // zh-TW
-//@line 1975 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 1986 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1307,11 +1318,11 @@ pref("print.postscript.nativecode.zh-TW", "big5");
 pref("print.postscript.nativefont.zh-TW", "ShanHeiSun-Light-B5-H");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2199 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2210 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2267 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2278 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2293 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2304 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2313 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
+//@line 2324 "/usr/local/src/Plamo/gnm/firefox/.work/mozilla/modules/libpref/src/init/all.js"
 
