@@ -8,16 +8,16 @@ PREFIX=/usr
 DOCPREFIX=${DOCPREFIX:-/usr/share/doc}
 
 SHORTNAME=firefox
-ORIGVER=1.5.0.1
+ORIGVER=1.5.0.2
 PKGVER=P1
 PACKAGE=$SHORTNAME-${ORIGVER/-/_}-i386-$PKGVER.tgz
 SRCPKG=$SHORTNAME-${ORIGVER/-/_}-i386-$PKGVER-Plamosrc.tar.gz
 
-SRCURL1=http://ftp.mozilla-japan.org/pub/mozilla.org/firefox/releases/1.5.0.1/source/firefox-1.5.0.1-source.tar.bz2
+SRCURL1=http://ftp.mozilla-japan.org/pub/mozilla.org/firefox/releases/1.5.0.2/source/firefox-1.5.0.2-source.tar.bz2
 SRC1=firefox-$ORIGVER-source.tar.bz2
 SRCDIR1=firefox-$ORIGVER
 
-LOCALEVER=1.5
+#LOCALEVER=1.5.0.2
 SRC11=firefox-${LOCALEVER:-$ORIGVER}-locales.tar.bz2
 SRC11_LOCALES=ja
 SRC11_COOPT=${LOCALEVER:+LOCALES_CO_TAG=FIREFOX_${LOCALEVER/./_}_RELEASE}
